//
// C++ Interface: CPartsysEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CPARTSYSEDITDLG_H
#define CPARTSYSEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_partsysdlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CPartsysEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CPartsysEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CPartsysEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
 
private slots:
 
protected:
    Ui::PartSysEditDlg ui;    
    FolderListItem *point;
    
private:
    QWidget *myParent;
};
#endif
